bluemath\_tk.predictor package
==============================

Submodules
----------

bluemath\_tk.predictor.awt module
---------------------------------

.. automodule:: bluemath_tk.predictor.awt
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.predictor.dwt module
---------------------------------

.. automodule:: bluemath_tk.predictor.dwt
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.predictor.indices module
-------------------------------------

.. automodule:: bluemath_tk.predictor.indices
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.predictor.itca module
----------------------------------

.. automodule:: bluemath_tk.predictor.itca
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.predictor.iwt module
---------------------------------

.. automodule:: bluemath_tk.predictor.iwt
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.predictor
   :members:
   :undoc-members:
   :show-inheritance:
